XmlWriter

Struct XmlWriter 

pub struct XmlWriter<W> { /* private fields */ }
A convenience wrapper for RPKI XML generation

This type only exposes things we need for the RPKI XML structures.

Implementations

Source

impl<W: Write> XmlWriter<W>

Generate the XML.

pub fn put_element<F>( &mut self, name: &str, attr: Option<&[(&str, &str)]>, op: F, ) -> Result<(), Error>
where F: FnOnce(&mut Self) -> Result<(), Error>,

Adds an element

pub fn put_text(&mut self, text: &str) -> Result<(), Error>

Puts some String in a characters element

pub fn put_base64_std(&mut self, bytes: &Bytes) -> Result<(), Error>

Converts bytes to base64 encoded Characters as the content, using the Standard character set, without padding.

pub fn put_base64_url_safe(&mut self, bytes: &[u8]) -> Result<(), Error>

Converts bytes to base64 encoded Characters as the content, using the URL safe character set and padding.

pub fn empty(&mut self) -> Result<(), Error>

Use this for convenience where empty content is required

Source

impl XmlWriter<()>

pub fn encode_vec<F>(op: F) -> Vec<u8>
where F: FnOnce(&mut XmlWriter<&mut Vec<u8>>) -> Result<(), Error>,

Call this to encode XML into a Vec

pub fn encode_to_file<F>(file: &mut File, op: F) -> Result<(), Error>
where F: FnOnce(&mut XmlWriter<&mut File>) -> Result<(), Error>,